## PyCIOT

Simple Python module utility for retreiving data from [Civil IOT Taiwan Data Service Platform](https://ci.taiwan.gov.tw/dsp/en/index.aspx) [(民生公共物聯網資料服務平台)](https://ci.taiwan.gov.tw/dsp/en/index.aspx).
